The AI Model Share Initiative
=============================

The objective of the AI Model Share Initiative is to develop tools that democratize access to, and understanding of, machine learning models. 

The Initiative acts as a non profit lab for ML innovation. Through the AI Model Share Platform (an all-in-one MLOps toolkit) we offer a Python library and integrated website that includes:

#. simple pathways to make models instantly sharable into web-dashboards and REST apis, 
#. the creation of integrated ML competitions to continuously improve model, 
#. robust model architecture metadata reporting tools, 
#. data and ipynb code sharing functionality, 
#. User publisher pages to display data science portfolios, 
#. and more.

On one end of this new platform’s workflow a machine learning engineer could submit and continuously improve a state of the art prediction model and at the other an end, people with little technical knowhow would be able to instantly make use of the model by submitting new data to generate model predictions, charts, and downloadable results within a simple, but elegant web-dashboard.

At the same time, the platform will serve as both a collaborative tool for rapid model improvement and a repository for model metadata that can be mined by researchers and engineers to inform further innovations in model development. 

